==> blesta-5.10.2.zip: blesta/plugins/order/language/fr_fr/signup.php <==
<?php
/**
 * Signup
 *
 * @package blesta
 * @subpackage blesta.language.fr_fr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Signup.!error.captcha.invalid'] = 'Le captcha saisi n\'est pas valide. Veuillez réessayer.';
$lang['Signup.!error.not_client_owner'] = 'Vous devez être connecté en tant que propriétaire du client pour continuer.';
$lang['Signup.!notice.force_email_usernames'] = 'Votre nom d\'utilisateur sera le même que votre adresse e-mail.';
$lang['Signup.!notice.email_verification'] = 'Un message a été envoyé pour vérifier votre adresse électronique. Veuillez procéder à la vérification dans les meilleurs délais.';
$lang['Signup.index.field_taxid'] = 'Numéro d\'identification fiscale/VATIN';
$lang['Signup.index.field_firstname'] = 'Prénom';
$lang['Signup.index.field_lastname'] = 'Nom de famille';
$lang['Signup.index.field_company'] = 'Entreprise/Org.';
$lang['Signup.index.field_address1'] = 'Adresse 1';
$lang['Signup.index.field_address2'] = 'Adresse 2';
$lang['Signup.index.field_city'] = 'Ville';
$lang['Signup.index.field_state'] = 'État/Province';
$lang['Signup.index.field_zip'] = 'Code postal';
$lang['Signup.index.field_country'] = 'Pays';
$lang['Signup.index.field_title'] = 'Titre';
$lang['Signup.index.field_phone'] = 'Téléphone';
$lang['Signup.index.field_fax'] = 'Fax';
$lang['Signup.index.field_email'] = 'Courriel';
$lang['Signup.index.field_username_type_email'] = 'Utiliser l\'email comme nom d\'utilisateur';
$lang['Signup.index.field_username_type_username'] = 'Spécifier un nom d\'utilisateur';
$lang['Signup.index.field_action_continue'] = 'Continuer comme %1$s %2$s';
$lang['Signup.index.field_action_login'] = 'Se connecter';
$lang['Signup.index.field_action_signup'] = 'Créer un compte';
$lang['Signup.index.field_username'] = 'Nom d\'utilisateur';
$lang['Signup.index.field_password'] = 'Mot de passe';
$lang['Signup.index.field_newpassword'] = 'Mot de passe';
$lang['Signup.index.field_confirmpassword'] = 'Confirmer le mot de passe';
$lang['Signup.index.field_receive_email_marketing'] = 'Je souhaite recevoir des courriels sur les nouveaux produits, services et offres.';
$lang['Signup.index.login_btn'] = 'Se connecter';
$lang['Signup.index.continue_btn'] = 'Poursuivre le paiement';
$lang['Signup.index.signup_btn'] = 'Créer un compte';
$lang['Signup.!error.email.blacklist'] = 'Votre commande ne peut pas être traitée pour le moment.';
$lang['Signup.index.field_recovery_email'] = 'Courriel de récupération (facultatif)';

==> blesta-5.11.4.zip: blesta/plugins/order/language/fr_fr/signup.php <==
<?php
/**
 * Signup
 *
 * @package blesta
 * @subpackage blesta.language.fr_fr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Signup.!error.captcha.invalid'] = 'Le captcha saisi n\'est pas valide. Veuillez réessayer.';
$lang['Signup.!error.not_client_owner'] = 'Vous devez être connecté en tant que propriétaire du client pour continuer.';
$lang['Signup.!notice.force_email_usernames'] = 'Votre nom d\'utilisateur sera le même que votre adresse e-mail.';
$lang['Signup.!notice.email_verification'] = 'Un message a été envoyé pour vérifier votre adresse électronique. Veuillez procéder à la vérification dans les meilleurs délais.';
$lang['Signup.index.field_taxid'] = 'Numéro d\'identification fiscale/VATIN';
$lang['Signup.index.field_firstname'] = 'Prénom';
$lang['Signup.index.field_lastname'] = 'Nom de famille';
$lang['Signup.index.field_company'] = 'Entreprise/Org.';
$lang['Signup.index.field_address1'] = 'Adresse 1';
$lang['Signup.index.field_address2'] = 'Adresse 2';
$lang['Signup.index.field_city'] = 'Ville';
$lang['Signup.index.field_state'] = 'État/Province';
$lang['Signup.index.field_zip'] = 'Code postal';
$lang['Signup.index.field_country'] = 'Pays';
$lang['Signup.index.field_title'] = 'Titre';
$lang['Signup.index.field_phone'] = 'Téléphone';
$lang['Signup.index.field_fax'] = 'Fax';
$lang['Signup.index.field_email'] = 'Courriel';
$lang['Signup.index.field_username_type_email'] = 'Utiliser l\'email comme nom d\'utilisateur';
$lang['Signup.index.field_username_type_username'] = 'Spécifier un nom d\'utilisateur';
$lang['Signup.index.field_action_continue'] = 'Continuer comme %1$s %2$s';
$lang['Signup.index.field_action_login'] = 'Se connecter';
$lang['Signup.index.field_action_signup'] = 'Créer un compte';
$lang['Signup.index.field_username'] = 'Nom d\'utilisateur';
$lang['Signup.index.field_password'] = 'Mot de passe';
$lang['Signup.index.field_newpassword'] = 'Mot de passe';
$lang['Signup.index.field_confirmpassword'] = 'Confirmer le mot de passe';
$lang['Signup.index.field_receive_email_marketing'] = 'Je souhaite recevoir des courriels sur les nouveaux produits, services et offres.';
$lang['Signup.index.login_btn'] = 'Se connecter';
$lang['Signup.index.continue_btn'] = 'Poursuivre le paiement';
$lang['Signup.index.signup_btn'] = 'Créer un compte';
$lang['Signup.!error.email.blacklist'] = 'Votre commande ne peut pas être traitée pour le moment.';
$lang['Signup.index.field_recovery_email'] = 'Courriel de récupération (facultatif)';
$lang['Signup.otp.field_submit'] = 'Se connecter';
$lang['Signup.otp.field_otp'] = 'Mot de passe unique';
$lang['Signup.otp.login_heading'] = 'Se connecter';
$lang['Signup.otp.description'] = 'Veuillez saisir votre mot de passe à usage unique.';
$lang['Signup.otp.page_title'] = 'Se connecter';
$lang['Signup.index.field_agree_tos'] = 'J\'ai lu et j\'accepte les <a href="%1$s" target="_blank">conditions générales d\'utilisation</a>.';
$lang['Signup.!error.invalid_agree_tos'] = 'Vous devez reconnaître que vous acceptez les conditions générales.';
